@@ -162,7 +162,7 @@ fixreg <- function (indep=rep(1,n), dep, n=length(dep),
   fpc <- rfpi(indep, dep, p, gv, ca, maxit, plot)   # WDC-iteration
   if (fpc$coll){
     print("Independent variables of whole data collinear. Break forced.")
-    break
+    return
   }
   imatrix <- c(sum(fpc$g)) # matrix of FPC size and intersections
   smatrix <- c(sum(fpc$g)) # matrix of FPC size and dissimilarities
